/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.control;

import java.awt.event.ActionEvent;
import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;

import javax.swing.AbstractAction;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import zleurtor.scanmanager.model.Utils;
import zleurtor.scanmanager.view.gui.GuiUtils;
import zleurtor.scanmanager.view.gui.LogDialog;
import zleurtor.scanmanager.view.gui.SlavesPanel;

/**
 * The action triggered when the user click the "log" button.
 *
 * @author Zleurtor
 */
public class LogAction extends AbstractAction {

    private static final long serialVersionUID = 4910719500000040636L;

    /**
     * A Logger...
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(LogAction.class);

    /**
     * The slaves panel for which the action shall performed.
     */
    private final SlavesPanel slavesPanel;

    /**
     * Constructs a new log action.
     *
     * @param theSlavesPanel The slaves panel for which the action shall performed.
     */
    public LogAction(final SlavesPanel theSlavesPanel) {
        super();
        this.slavesPanel = theSlavesPanel;
    }

    @Override
    public final void actionPerformed(final ActionEvent evt) {
        try {
            final BufferedReader reader = new BufferedReader(new FileReader(Utils.getLogFile()));
            new LogDialog(slavesPanel, "Master", null, reader, Utils.getLogLevel());
        } catch (final IOException e) {
            GuiUtils.showWarning(e, slavesPanel);
            LOGGER.warn(e.getMessage(), e);
        }
    }

}
