/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.control;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;

import zleurtor.scanmanager.model.Master;
import zleurtor.scanmanager.view.SlaveInformation;

/**
 * The action triggered when the user click a thumbnail in order to start a preview.
 *
 * @author Zleurtor
 */
public class StreamAction extends AbstractAction {

    private static final long serialVersionUID = -7918676056775110670L;

    /**
     * The model object which has to execute the save process.
     */
    private final Master master;

    /**
     * Constructs a new stream action.
     *
     * @param theMaster The model object which has to execute the save process.
     */
    public StreamAction(final Master theMaster) {
        super();
        this.master = theMaster;
    }

    @Override
    public final void actionPerformed(final ActionEvent evt) {
        final SlaveInformation si = (SlaveInformation) evt.getSource();
        master.stream(si.getName(), si.getIp());
    }

}
