/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.control;

import java.awt.event.ActionEvent;
import java.io.File;

import javax.swing.AbstractAction;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;

import zleurtor.scanmanager.model.Master;
import zleurtor.scanmanager.view.ResourcesManager;
import zleurtor.scanmanager.view.gui.SlavesPanel;
import zleurtor.scanmanager.view.gui.TrashDialog;

/**
 * The action triggered when the user click the "Trash" button.
 *
 * @author Zleurtor
 */
public class TrashAction extends AbstractAction {

    private static final long serialVersionUID = 5154883248777153558L;

    /**
     * The dialog to display when the user trigger the action.
     */
    private TrashDialog dialog;

    /**
     * The model object which has to execute the save process.
     */
    private final Master master;

    /**
     * The slaves panel involved in the action.
     */
    private final SlavesPanel panel;

    /**
     * Constructs a new trash action.
     *
     * @param theMaster The model object which has to execute the save process.
     * @param thePanel The slaves panel involved in the action.
     */
    public TrashAction(final Master theMaster, final SlavesPanel thePanel) {
        super();
        this.master = theMaster;
        this.panel = thePanel;
    }

    @Override
    public final void actionPerformed(final ActionEvent evt) {
        final File[] snapshotSets = master.getSnapshotSets();

        if (snapshotSets.length == 0) {
            JOptionPane.showMessageDialog(panel, ResourcesManager.getInstance().getString(ResourcesManager.KEY_TEXT_NOSNAPSHOT));
            return;
        }

        if (dialog == null) {
            dialog = new TrashDialog(SwingUtilities.getWindowAncestor(panel));
        }

        dialog.setSnapshotSets(snapshotSets);
        dialog.pack();
        dialog.setLocationRelativeTo(SwingUtilities.getWindowAncestor(panel));
        dialog.setVisible(true);

        final File[] selectedSnapshotSets = dialog.getSelectedSnapshotSets();
        if (selectedSnapshotSets != null) {
            master.trash(selectedSnapshotSets);
        }
    }

}
