/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.model.events;

import java.util.EventObject;

/**
 * The class of events fired by the artifact repository manager connector.
 *
 * @author Zleurtor
 */
public class ArtifactRepositoryManagerConnectorEvent extends EventObject {

    private static final long serialVersionUID = 3018321468914451905L;

    /**
     * The currently downloading artifact size.
     */
    private final int artifactSize;

    /**
     * The artifact downloaded quantity.
     */
    private final int downloadedSize;

    /**
     * Constructs a new artifact repository manager connector event using the specified source, artifact size and downloaded size.
     *
     * @param source The object which fired this event.
     * @param theArtifactSize The currently downloading artifact size.
     * @param theDownloadedSize The artifact downloaded quantity.
     */
    public ArtifactRepositoryManagerConnectorEvent(final Object source, final int theArtifactSize, final int theDownloadedSize) {
        super(source);
        this.artifactSize = theArtifactSize;
        this.downloadedSize = theDownloadedSize;
    }

    /**
     * Returns the currently downloading artifact size.
     *
     * @return The currently downloading artifact size.
     */
    public final int getArtifactSize() {
        return artifactSize;
    }

    /**
     * Returns the artifact downloaded quantity.
     *
     * @return The artifact downloaded quantity.
     */
    public final int getDownloadedSize() {
        return downloadedSize;
    }

}
