/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.model.events;

import java.util.EventObject;

/**
 * The class of events fired by the master.
 *
 * @author Zleurtor
 */
public class MasterEvent extends EventObject {

    private static final long serialVersionUID = -4550703481123793263L;

    /**
     * The IP of the slave involved in this event.
     */
    private final String ip;

    /**
     * The name of the slave involved in this event.
     */
    private final String name;

    /**
     * The data (specific to each master event).
     */
    private final Object data;

    /**
     * Constructs a new master event using the specified source, ip, name and snapshot filename.
     *
     * @param source The object which fired this event.
     * @param theIp The IP of the slave involved in this event.
     * @param theName The name of the slave involved in this event.
     * @param theData The event specific data.
     */
    public MasterEvent(final Object source, final String theIp, final String theName, final Object theData) {
        super(source);
        this.ip = theIp;
        this.name = theName;
        this.data = theData;
    }

    /**
     * Returns the IP of the slave involved in this event.
     *
     * @return The IP of the slave involved in this event.
     */
    public final String getIp() {
        return ip;
    }

    /**
     * Returns the name of the slave involved in this event.
     *
     * @return The name of the slave involved in this event.
     */
    public final String getName() {
        return name;
    }

    /**
     * Returns the data (specific to each master event).
     *
     * @return The master event data.
     */
    public final Object getData() {
        return data;
    }

}
