/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.model.events;

import java.util.EventObject;

/**
 * The class representing a master updater event.
 *
 * @author Zleurtor
 */
public class MasterUpdaterEvent extends EventObject {

    private static final long serialVersionUID = -4898346434405560652L;

    /**
     * The currently downloading artifact size.
     */
    private final int artifactSize;

    /**
     * The artifact downloaded quantity.
     */
    private final int downloadedSize;

    /**
     * Creates a master updater event having the specified source.
     *
     * @param source The source of the event which shall be created.
     */
    public MasterUpdaterEvent(final Object source) {
        super(source);
        this.artifactSize = -1;
        this.downloadedSize = -1;
    }

    /**
     * Creates a master updater event having the specified source.
     *
     * @param source The source of the event which shall be created.
     * @param theArtifactSize The currently downloading artifact size.
     * @param theDownloadedSize The artifact downloaded quantity.
     */
    public MasterUpdaterEvent(final Object source, final int theArtifactSize, final int theDownloadedSize) {
        super(source);
        this.artifactSize = theArtifactSize;
        this.downloadedSize = theDownloadedSize;
    }

    /**
     * Returns the currently downloading artifact size.
     *
     * @return The currently downloading artifact size.
     */
    public final int getArtifactSize() {
        return artifactSize;
    }

    /**
     * Returns the artifact downloaded quantity.
     *
     * @return The artifact downloaded quantity.
     */
    public final int getDownloadedSize() {
        return downloadedSize;
    }

}
