/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.model.events;

import java.util.EventListener;

/**
 * The interface which all the master updater listeners shall implements.
 *
 * @author Zleurtor
 */
public interface MasterUpdaterListener extends EventListener {

    /**
     * The methode launched when an update found event is fired.
     *
     * @param evt The event object representing the master updater event.
     */
    void updateFound(MasterUpdaterEvent evt);

    /**
     * The methode launched when an update download start event is fired.
     *
     * @param evt The event object representing the master updater event.
     */
    void downloading(MasterUpdaterEvent evt);

    /**
     * The methode launched when an update install start event is fired.
     *
     * @param evt The event object representing the master updater event.
     */
    void installing(MasterUpdaterEvent evt);

    /**
     * The methode launched when an update finished event is fired.
     *
     * @param evt The event object representing the master updater event.
     */
    void finished(MasterUpdaterEvent evt);

}
