/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.model.messages;

import java.io.IOException;
import java.io.StringWriter;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.TransformerFactoryConfigurationError;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import javax.xml.xpath.XPathExpressionException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.SAXException;

/**
 * The message sent by the server to ask the slaves to start a preview.
 *
 * @author Zleurtor
 */
public class StreamMessage extends AbstractMessage {

    private static final long serialVersionUID = -5473060504339208298L;

    /**
     * Constructs a new "stream" message using the specified options.
     */
    public StreamMessage() {
        super();
    }

    @Override
    protected final String toXml()
            throws ParserConfigurationException, TransformerFactoryConfigurationError, TransformerException, IOException {
        final Document document = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();

        final Element messageElt = document.createElement("message");
        messageElt.setAttribute("type", getClass().getName());
        document.appendChild(messageElt);

        try (StringWriter writer = new StringWriter()) {
            final Transformer transformer = TransformerFactory.newInstance().newTransformer();
            transformer.setOutputProperty(OutputKeys.INDENT, "yes");
            transformer.setOutputProperty("{http://xml.apache.org/xslt}indent-amount", "3");
            transformer.transform(new DOMSource(document), new StreamResult(writer));
            return writer.toString();
        }
    }

    @Override
    protected final AbstractMessage fromXml(final String xml)
            throws SAXException, IOException, ParserConfigurationException, XPathExpressionException {
        return this;
    }

}
