/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.awt.HeadlessException;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.util.Calendar;
import java.util.GregorianCalendar;

import javax.swing.ImageIcon;
import javax.swing.JOptionPane;
import javax.swing.SwingUtilities;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import zleurtor.scanmanager.model.Configuration;
import zleurtor.scanmanager.view.ResourcesManager;

/**
 * A specific button for the "about" action.
 *
 * @author Zleurtor
 */
public class AboutButton extends AbstractToolBarButton implements ActionListener {

    private static final long serialVersionUID = 7750132565053349866L;

    /**
     * A Logger...
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(AboutButton.class);

    /**
     * Constructs a new "about" button.
     * @throws IOException If an Input/Output errors occurs during icon reading.
     */
    public AboutButton() throws IOException {
        super(ResourcesManager.getInstance().getImage(ResourcesManager.KEY_ICON_ABOUT),
                ResourcesManager.getInstance().getString(ResourcesManager.KEY_TOOLTIP_ABOUT));
        addActionListener(this);
    }

    @Override
    public final void actionPerformed(final ActionEvent evt) {
        try {
            JOptionPane.showMessageDialog(
                    SwingUtilities.getWindowAncestor(this),
                    ResourcesManager.getInstance().getString(ResourcesManager.KEY_TEXT_ABOUT,
                            Configuration.getInstance().getString("version"),
                            Integer.toString(new GregorianCalendar().get(Calendar.YEAR))),
                    ResourcesManager.getInstance().getString(ResourcesManager.KEY_TITLE_ABOUT),
                    JOptionPane.INFORMATION_MESSAGE,
                    new ImageIcon(ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_GPLV3)));
        } catch (final HeadlessException | IOException e) {
            GuiUtils.showWarning(e, this);
            LOGGER.warn(e.getMessage(), e);
        }
    }

}
