/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.JDialog;
import javax.swing.JProgressBar;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The dialog displaying information about the update events.
 *
 * @author Zleurtor
 */
public abstract class AbstractProgressDialog extends JDialog {

    private static final long serialVersionUID = -6196030577667100008L;

    /**
     * The progress bar displaying the progress.
     */
    private final JProgressBar progressBar = new JProgressBar();

    /**
     * Constructs a new update dialog.
     */
    public AbstractProgressDialog() {
        super((Frame) null, false);

        setContentPane(new ContentPanel());

        final int margin = ResourcesManager.getInstance().getInt(ResourcesManager.KEY_WAITPANEL_MARGIN);

        setLayout(new GridBagLayout());
        add(progressBar,
                new GridBagConstraints(
                        0, 1, 1, 1, 1, 0,
                        GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL,
                        new Insets(margin / 2, margin, margin, margin), 0, 0));

        pack();
        setLocationRelativeTo(null);
        setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
    }

    /**
     * Returns the progress bar displaying the progress.
     *
     * @return The progress bar displaying the progress.
     */
    public JProgressBar getProgressBar() {
        return progressBar;
    }

}
