/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.awt.Image;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;

import javax.swing.ImageIcon;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import zleurtor.scanmanager.model.Configuration;
import zleurtor.scanmanager.view.ResourcesManager;

/**
 * A specific button for the "sound" action.
 *
 * @author Zleurtor
 */
public class ColorsButton extends AbstractToolBarButton implements ActionListener {

    private static final long serialVersionUID = 5683608591953885240L;

    /**
     * A Logger...
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(ColorsButton.class);

    /**
     * The image for the sound on icons.
     */
    private static final Image POLYCHROME;

    /**
     * The image for the sound off icons.
     */
    private static final Image MONOCHROME;

    static {
        Image polychrome = null;
        try {
            polychrome = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_ICON_POLYCHROME);
        } catch (final IOException e) {
            GuiUtils.showWarning(e, null);
            LOGGER.warn(e.getMessage(), e);
        }
        POLYCHROME = polychrome;

        Image monochrome = null;
        try {
            monochrome = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_ICON_MONOCHROME);
        } catch (final IOException e) {
            GuiUtils.showWarning(e, null);
            LOGGER.warn(e.getMessage(), e);
        }
        MONOCHROME = monochrome;
    }

    /**
     * Constructs a new "sound" button.
     *
     * @throws IOException If an Input/Output errors occurs during icon reading.
     */
    public ColorsButton() throws IOException {
        super((Boolean.parseBoolean(Configuration.getInstance().getString("polychrome"))) ? POLYCHROME : MONOCHROME,
                ResourcesManager.getInstance().getString(ResourcesManager.KEY_TOOLTIP_CHROMACITY));
        addActionListener(this);

        if ((Boolean.parseBoolean(Configuration.getInstance().getString("polychrome")))) {
            setIcon(new ImageIcon(POLYCHROME));
            setDefaultIcon(new ImageIcon(POLYCHROME));
            setOverflyIcon(new ImageIcon(POLYCHROME));
            setActiveIcon(new ImageIcon(POLYCHROME));
        } else {
            setIcon(new ImageIcon(MONOCHROME));
            setDefaultIcon(new ImageIcon(MONOCHROME));
            setOverflyIcon(new ImageIcon(MONOCHROME));
            setActiveIcon(new ImageIcon(MONOCHROME));
        }
        repaint();
    }

    @Override
    public final void actionPerformed(final ActionEvent e) {
        if ((Boolean.parseBoolean(Configuration.getInstance().getString("polychrome")))) {
            Configuration.getInstance().setString("polychrome", "false");
            setDefaultIcon(new ImageIcon(MONOCHROME));
            setOverflyIcon(new ImageIcon(MONOCHROME));
            setActiveIcon(new ImageIcon(MONOCHROME));
        } else {
            Configuration.getInstance().setString("polychrome", "true");
            setDefaultIcon(new ImageIcon(POLYCHROME));
            setOverflyIcon(new ImageIcon(POLYCHROME));
            setActiveIcon(new ImageIcon(POLYCHROME));
        }
    }

}
