/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.awt.Component;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Insets;
import java.io.IOException;

import javax.swing.border.Border;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The border of the window's main panel.
 *
 * @author Zleurtor
 */
public class ContentBorder implements Border {

    /**
     * A logger...
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(ContentBorder.class);

    /**
     * The border's top image.
     */
    private static final Image TOP;

    /**
     * The border's bottom image.
     */
    private static final Image BOTTOM;

    /**
     * The border's left image.
     */
    private static final Image LEFT;

    /**
     * The border's right image.
     */
    private static final Image RIGHT;

    /**
     * The border's top left image.
     */
    private static final Image TOP_LEFT;

    /**
     * The border's top right image.
     */
    private static final Image TOP_RIGHT;

    /**
     * The border's bottom left image.
     */
    private static final Image BOTTOM_LEFT;

    /**
     * The border's bottom right image.
     */
    private static final Image BOTTOM_RIGHT;

    static {
        Image top = null;
        Image bottom = null;
        Image left = null;
        Image right = null;
        Image topLeft = null;
        Image topRight = null;
        Image bottomLeft = null;
        Image bottomRight = null;

        try {
            top = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_BORDER_TOP);
            bottom = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_BORDER_BOTTOM);
            left = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_BORDER_LEFT);
            right = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_BORDER_RIGHT);
            topLeft = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_BORDER_TOPLEFT);
            topRight = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_BORDER_TOPRIGHT);
            bottomLeft = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_BORDER_BOTTOMLEFT);
            bottomRight = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_BORDER_BOTTOMRIGHT);
        } catch (final IOException e) {
            GuiUtils.showWarning("Cannot load the border images: " + e.getMessage(), e, null);
            LOGGER.warn("Cannot load the border images: " + e.getMessage(), e);
        }

        TOP = top;
        BOTTOM = bottom;
        LEFT = left;
        RIGHT = right;
        TOP_LEFT = topLeft;
        TOP_RIGHT = topRight;
        BOTTOM_LEFT = bottomLeft;
        BOTTOM_RIGHT = bottomRight;
    }

    @Override
    public final void paintBorder(final Component c, final Graphics g, final int x, final int y, final int width, final int height) {
        g.drawImage(TOP,
                TOP_LEFT.getWidth(c), 0, c.getWidth() - TOP_RIGHT.getWidth(c), TOP.getHeight(c),
                0, 0, TOP.getWidth(c), TOP.getHeight(c), c);
        g.drawImage(BOTTOM,
                BOTTOM_LEFT.getWidth(c), c.getHeight() - BOTTOM.getHeight(c), c.getWidth() - BOTTOM_RIGHT.getWidth(c), c.getHeight(),
                0, 0, BOTTOM.getWidth(c), BOTTOM.getHeight(c), c);
        g.drawImage(LEFT,
                0, TOP_LEFT.getHeight(c), LEFT.getWidth(c), c.getHeight() - BOTTOM_LEFT.getHeight(c),
                0, 0, LEFT.getWidth(c), LEFT.getHeight(c), c);
        g.drawImage(RIGHT,
                c.getWidth() - RIGHT.getWidth(c), TOP_RIGHT.getHeight(c), c.getWidth(), c.getHeight() - BOTTOM_RIGHT.getHeight(c),
                0, 0, RIGHT.getWidth(c), RIGHT.getHeight(c), c);
        g.drawImage(TOP_LEFT,
                0, 0, TOP_LEFT.getWidth(c), TOP_LEFT.getHeight(c),
                0, 0, TOP_LEFT.getWidth(c), TOP_LEFT.getHeight(c), c);
        g.drawImage(TOP_RIGHT,
                c.getWidth() - TOP_RIGHT.getWidth(c), 0, c.getWidth(), TOP_RIGHT.getHeight(c),
                0, 0, TOP_RIGHT.getWidth(c), TOP_RIGHT.getHeight(c), c);
        g.drawImage(BOTTOM_LEFT,
                0, c.getHeight() - BOTTOM_LEFT.getHeight(c), BOTTOM_LEFT.getWidth(c), c.getHeight(),
                0, 0, BOTTOM_LEFT.getWidth(c), BOTTOM_LEFT.getHeight(c), c);
        g.drawImage(BOTTOM_RIGHT,
                c.getWidth() - BOTTOM_RIGHT.getWidth(c), c.getHeight() - BOTTOM_RIGHT.getHeight(c), c.getWidth(), c.getHeight(),
                0, 0, BOTTOM_RIGHT.getWidth(c), BOTTOM_RIGHT.getHeight(c), c);
    }

    @Override
    public final Insets getBorderInsets(final Component c) {
        return new Insets(
                TOP.getHeight(c),
                LEFT.getWidth(c),
                BOTTOM.getHeight(c),
                RIGHT.getWidth(c));
    }

    @Override
    public final boolean isBorderOpaque() {
        return true;
    }

}
