/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.awt.Graphics;
import java.awt.Image;
import java.io.IOException;

import javax.swing.JPanel;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The background panel of a window.
 *
 * @author Zleurtor
 */
public final class ContentPanel extends JPanel {

    private static final long serialVersionUID = -3762373097052599930L;

    /**
     * A logger...
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(ContentPanel.class);

    /**
     * The background image.
     */
    private static final Image BACKGROUND;

    static {
        Image background = null;
        try {
            background = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_IMAGE_BACKGROUND);
        } catch (final IOException e) {
            GuiUtils.showWarning("Cannot load the background image: " + e.getMessage(), e, null);
            LOGGER.warn("Cannot load the background image: " + e.getMessage(), e);
        }

        BACKGROUND = background;
    }

    /**
     * Constructs an empty content panel.
     */
    public ContentPanel() {
        super();
        setBorder(new ContentBorder());
    }

    @Override
    protected void paintComponent(final Graphics g) {
        super.paintComponent(g);

        if (BACKGROUND != null) {
            g.drawImage(BACKGROUND, 0, 0, getWidth(), getHeight(), 0, 0, BACKGROUND.getWidth(this), BACKGROUND.getHeight(this), this);
        }
    }

}
