/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.awt.Component;

import javax.swing.JOptionPane;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * A class containing utility methods.
 *
 * @author Zleurtor
 */
public final class GuiUtils {

    /**
     * A private constructor for this utility class.
     */
    private GuiUtils() { }

    /**
     * Shows a warning message in a dialog.
     *
     * @param message The message to display.
     * @param parentComponent The component for which the warning dialog shall be displayed.
     */
    public static void showWarning(final String message, final Component parentComponent) {
        JOptionPane.showMessageDialog(parentComponent,
                message,
                ResourcesManager.getInstance().getString(ResourcesManager.KEY_TITLE_WARNING),
                JOptionPane.WARNING_MESSAGE);
    }

    /**
     * Shows an error message in a dialog.
     *
     * @param message The message to display.
     * @param parentComponent The component for which the error dialog shall be displayed.
     */
    public static void showError(final String message, final Component parentComponent) {
        JOptionPane.showMessageDialog(parentComponent,
                message,
                ResourcesManager.getInstance().getString(ResourcesManager.KEY_TITLE_ERROR),
                JOptionPane.ERROR_MESSAGE);
    }

    /**
     * Shows an warning message in a dialog.
     *
     * @param message The message to display.
     * @param t The throwable to display.
     * @param parentComponent The component for which the error dialog shall be displayed.
     */
    public static void showWarning(final String message, final Throwable t, final Component parentComponent) {
        String m = message;
        for (final StackTraceElement element : t.getStackTrace()) {
            m += "\n\t" + element;
        }

        showWarning(m, parentComponent);
    }

    /**
     * Shows an error message in a dialog.
     *
     * @param message The message to display.
     * @param t The throwable to display.
     * @param parentComponent The component for which the error dialog shall be displayed.
     */
    public static void showError(final String message, final Throwable t, final Component parentComponent) {
        String m = message;
        for (final StackTraceElement element : t.getStackTrace()) {
            m += "\n\t" + element;
        }

        showError(m, parentComponent);
    }

    /**
     * Shows an warning message in a dialog.
     *
     * @param t The throwable to display.
     * @param parentComponent The component for which the error dialog shall be displayed.
     */
    public static void showWarning(final Throwable t, final Component parentComponent) {
        String m = t.getLocalizedMessage();
        for (final StackTraceElement element : t.getStackTrace()) {
            m += "\n\t" + element;
        }

        showWarning(m, parentComponent);
    }

    /**
     * Shows an error message in a dialog.
     *
     * @param t The throwable to display.
     * @param parentComponent The component for which the error dialog shall be displayed.
     */
    public static void showError(final Throwable t, final Component parentComponent) {
        String m = t.getLocalizedMessage();
        for (final StackTraceElement element : t.getStackTrace()) {
            m += "\n\t" + element;
        }

        showError(m, parentComponent);
    }

}
