/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.io.IOException;

import zleurtor.scanmanager.control.SaveAction;
import zleurtor.scanmanager.model.Master;
import zleurtor.scanmanager.view.ResourcesManager;

/**
 * A specific button for the "save" action.
 *
 * @author Zleurtor
 */
public class SaveButton extends AbstractToolBarButton {

    private static final long serialVersionUID = 3048949131178749636L;

    /**
     * The "save" action triggered when the user click the button.
     */
    private final SaveAction action;

    /**
     * Constructs a new "save" button.
     *
     * @param master The master that shall execute the save action.
     * @throws IOException If an Input/Output errors occurs during icon reading.
     */
    public SaveButton(final Master master) throws IOException {
        super(ResourcesManager.getInstance().getImage(ResourcesManager.KEY_ICON_SAVE),
                ResourcesManager.getInstance().getString(ResourcesManager.KEY_TOOLTIP_SAVE));
        action = new SaveAction(master);
        addActionListener(action);
    }

    /**
     * Sets the panel containing snapshots to save.
     *
     * @param slavesPanel The panel containing snapshots to save.
     */
    public final void setSlavesPanel(final SlavesPanel slavesPanel) {
        action.setSlavesPanel(slavesPanel);
    }

}
