/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.awt.GridBagConstraints;
import java.awt.Insets;

import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.SwingConstants;

import org.apache.log4j.lf5.LogLevel;

import zleurtor.scanmanager.model.events.MasterEvent;
import zleurtor.scanmanager.model.events.MasterListener;
import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The dialog displaying information about the update events.
 *
 * @author Zleurtor
 */
public class SaveDialog extends AbstractProgressDialog implements MasterListener {

    private static final long serialVersionUID = 1752198079515255790L;

    /**
     * The label displaying update download information.
     */
    private final JLabel savingLabel =
            new JLabel(ResourcesManager.getInstance().getString(ResourcesManager.KEY_TEXT_SAVING), SwingConstants.CENTER);

    /**
     * Constructs a new update dialog.
     */
    public SaveDialog() {
        super();

        setTitle(ResourcesManager.getInstance().getString(ResourcesManager.KEY_TITLE_SAVEDIALOG));

        final int margin = ResourcesManager.getInstance().getInt(ResourcesManager.KEY_WAITPANEL_MARGIN);

        add(savingLabel,
                new GridBagConstraints(
                        0, 0, 1, 1, 0, 0,
                        GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL,
                        new Insets(margin, margin, margin / 2, margin), 0, 0));

        pack();
        setLocationRelativeTo(null);
        setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
    }

    @Override
    public void slavesCleared() { }

    @Override
    public void newSlave(final MasterEvent evt) { }

    @Override
    public void slaveQuit(final MasterEvent evt) { }

    @Override
    public void snapshotSuccess(final MasterEvent evt) { }

    @Override
    public void snapshotError(final MasterEvent evt) { }

    @Override
    public void snapshotsCleared() { }

    @Override
    public void streamError(final MasterEvent evt) { }

    @Override
    public void log(final MasterEvent evt, final LogLevel level) { }

    @Override
    public void logLevelError(final MasterEvent evt) { }

    @Override
    public void logLevelSuccess(final MasterEvent evt) { }

    @Override
    public void options(final MasterEvent evt) { }

    @Override
    public final synchronized void fileSaved(final MasterEvent evt) {
        final int value = ((int[]) evt.getData())[0];
        final int maximum = ((int[]) evt.getData())[1];

        getProgressBar().setMinimum(0);
        getProgressBar().setMaximum(maximum);
        getProgressBar().setValue(value);

        if (value == maximum) {
            setVisible(false);
        }
    }

}
