/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.io.IOException;

import zleurtor.scanmanager.control.SnapshotAction;
import zleurtor.scanmanager.model.Master;
import zleurtor.scanmanager.view.ResourcesManager;

/**
 * A specific button for the "snapshot" action.
 *
 * @author Zleurtor
 */
public class SnapshotButton extends AbstractToolBarButton {

    private static final long serialVersionUID = -5193385120418740467L;

    /**
     * Constructs a new "snapshot" button.
     *
     * @param master The master that shall execute the snapshot action.
     * @param slavesPanel The panel containing information to take snapshots.
     * @throws IOException If an Input/Output errors occurs during icon reading.
     */
    public SnapshotButton(final Master master, final SlavesPanel slavesPanel) throws IOException {
        super(ResourcesManager.getInstance().getImage(ResourcesManager.KEY_ICON_SNAPSHOT),
                ResourcesManager.getInstance().getString(ResourcesManager.KEY_TOOLTIP_SNAPSHOT));
        addActionListener(new SnapshotAction(master, slavesPanel));
    }

}
