/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.awt.Image;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;

import javax.swing.ImageIcon;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import zleurtor.scanmanager.model.Configuration;
import zleurtor.scanmanager.view.ResourcesManager;

/**
 * A specific button for the "sound" action.
 *
 * @author Zleurtor
 */
public class SoundButton extends AbstractToolBarButton implements ActionListener {

    private static final long serialVersionUID = -6342075007346887944L;

    /**
     * A Logger...
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(SoundButton.class);

    /**
     * The image for the sound on icons.
     */
    private static final Image SOUND_ON;

    /**
     * The image for the sound off icons.
     */
    private static final Image SOUND_OFF;

    static {
        Image soundOn = null;
        try {
            soundOn = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_ICON_SOUNDON);
        } catch (final IOException e) {
            GuiUtils.showWarning(e, null);
            LOGGER.warn(e.getMessage(), e);
        }
        SOUND_ON = soundOn;

        Image soundOff = null;
        try {
            soundOff = ResourcesManager.getInstance().getImage(ResourcesManager.KEY_ICON_SOUNDOFF);
        } catch (final IOException e) {
            GuiUtils.showWarning(e, null);
            LOGGER.warn(e.getMessage(), e);
        }
        SOUND_OFF = soundOff;
    }

    /**
     * Constructs a new "sound" button.
     *
     * @throws IOException If an Input/Output errors occurs during icon reading.
     */
    public SoundButton() throws IOException {
        super((Boolean.parseBoolean(Configuration.getInstance().getString("sound"))) ? SOUND_ON : SOUND_OFF,
                ResourcesManager.getInstance().getString(ResourcesManager.KEY_TOOLTIP_SOUND));
        addActionListener(this);
    }

    @Override
    public final void actionPerformed(final ActionEvent e) {
        if ((Boolean.parseBoolean(Configuration.getInstance().getString("sound")))) {
            Configuration.getInstance().setString("sound", "false");
            setDefaultIcon(new ImageIcon(ResourcesManager.colorize(SOUND_OFF, getForeground())));
            setOverflyIcon(new ImageIcon(ResourcesManager.colorize(SOUND_OFF,
                    ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            setActiveIcon(new ImageIcon(ResourcesManager.colorize(SOUND_OFF,
                    ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE).brighter())));
        } else {
            Configuration.getInstance().setString("sound", "true");
            setDefaultIcon(new ImageIcon(ResourcesManager.colorize(SOUND_ON, getForeground())));
            setOverflyIcon(new ImageIcon(ResourcesManager.colorize(SOUND_ON,
                    ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            setActiveIcon(new ImageIcon(ResourcesManager.colorize(SOUND_ON,
                    ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE).brighter())));
        }
    }

}
