/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.gui;

import java.awt.GridBagConstraints;
import java.awt.Insets;

import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.SwingConstants;

import zleurtor.scanmanager.model.events.MasterUpdaterEvent;
import zleurtor.scanmanager.model.events.MasterUpdaterListener;
import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The dialog displaying information about the update events.
 *
 * @author Zleurtor
 */
public class UpdateDialog extends AbstractProgressDialog implements MasterUpdaterListener {

    private static final long serialVersionUID = 1752198079515255790L;

    /**
     * The label displaying update download information.
     */
    private final JLabel downloadingLabel =
            new JLabel(ResourcesManager.getInstance().getString(ResourcesManager.KEY_TEXT_DOWNLOADINGUPDATE), SwingConstants.CENTER);

    /**
     * The label displaying update install information.
     */
    private final JLabel installingLabel =
            new JLabel(ResourcesManager.getInstance().getString(ResourcesManager.KEY_TEXT_INSTALLINGUPDATE), SwingConstants.CENTER);

    /**
     * Constructs a new update dialog.
     */
    public UpdateDialog() {
        super();

        setTitle(ResourcesManager.getInstance().getString(ResourcesManager.KEY_TITLE_UPDATEDIALOG));

        final int margin = ResourcesManager.getInstance().getInt(ResourcesManager.KEY_WAITPANEL_MARGIN);

        add(downloadingLabel,
                new GridBagConstraints(
                        0, 0, 1, 1, 0, 0,
                        GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL,
                        new Insets(margin, margin, margin / 2, margin), 0, 0));
        add(installingLabel,
                new GridBagConstraints(
                        0, 0, 1, 1, 0, 0,
                        GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL,
                        new Insets(margin, margin, margin / 2, margin), 0, 0));

        pack();
        setLocationRelativeTo(null);
        setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
    }

    @Override
    public final void updateFound(final MasterUpdaterEvent evt) {
        downloadingLabel.setVisible(false);
        installingLabel.setVisible(false);

        setVisible(true);
    }

    @Override
    public final void downloading(final MasterUpdaterEvent evt) {
        downloadingLabel.setVisible(true);
        installingLabel.setVisible(false);

        getProgressBar().setIndeterminate(false);
        getProgressBar().setMinimum(0);
        getProgressBar().setMaximum(evt.getArtifactSize());
        getProgressBar().setValue(evt.getDownloadedSize());
    }

    @Override
    public final void installing(final MasterUpdaterEvent evt) {
        downloadingLabel.setVisible(false);
        installingLabel.setVisible(true);
        getProgressBar().setIndeterminate(true);

        setVisible(true);
    }

    @Override
    public final void finished(final MasterUpdaterEvent evt) {
        dispose();
        setVisible(false);
    }

}
