/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.RenderingHints;

import javax.swing.plaf.basic.BasicArrowButton;

/**
 * JButton object that draws a scaled Arrow in one of the cardinal directions.
 *
 * @author Zleurtor
 */
public class ScanManagerArrowButton extends BasicArrowButton {

    private static final long serialVersionUID = -5039721253709028794L;

    /**
     * Creates a ScanManagerArrowButton whose arrow is drawn in the specified direction.
     *
     * @param direction The direction of the arrow; one of SwingConstants.NORTH, SwingConstants.SOUTH, SwingConstants.EAST or
     *                  SwingConstants.WEST.
     */
    public ScanManagerArrowButton(final int direction) {
        super(direction);
        setContentAreaFilled(false);
        setOpaque(false);
    }

    @Override
    public final void paint(final Graphics g) {
        ((Graphics2D) g).setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);

        g.setColor(getForeground());

        final int triangle = 3;

        switch (getDirection()) {
            case NORTH:
                g.fillPolygon(
                        new int[] { getWidth() / 2, getWidth() - 1, 1 },
                        new int[] { 1, getHeight() - 1, getHeight() - 1 },
                        triangle);
                break;
            case SOUTH:
                g.fillPolygon(
                        new int[] { getWidth() / 2, getWidth() - 1, 1 },
                        new int[] { getHeight() - 1, 1, 1 },
                        triangle);
                break;
            case EAST:
                g.fillPolygon(
                        new int[] { 1, getWidth() - 1, 1 },
                        new int[] { 1, getHeight() / 2, getHeight() - 1 },
                        triangle);
                break;
            case WEST:
                g.fillPolygon(
                        new int[] { getWidth() - 1, getWidth() - 1, 1 },
                        new int[] { 1, getHeight() - 1, getHeight() / 2 },
                        triangle);
                break;
            default:
                break;
        }
    }

}
