/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import java.io.IOException;

import javax.swing.ImageIcon;
import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicCheckBoxUI;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import zleurtor.scanmanager.view.ResourcesManager;
import zleurtor.scanmanager.view.gui.GuiUtils;

/**
 * The 3D Scan Manager personalized check box UI.
 *
 * @author Zleurtor
 */
public class ScanManagerCheckBoxUI extends BasicCheckBoxUI {

    /**
     * A logger...
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(ScanManagerCheckBoxUI.class);

    /**
     * Create the UI.
     *
     * @param c The component to which the UI shall be applied.
     * @return The unique UI instance.
     */
    public static ComponentUI createUI(final JComponent c) {
        final ScanManagerCheckBoxUI checkBoxUI = new ScanManagerCheckBoxUI();

        final JCheckBox cb = (JCheckBox) c;
        cb.setOpaque(false);
        try {
            cb.setSelectedIcon(new ImageIcon(ResourcesManager.getInstance().getImage(ResourcesManager.KEY_CHECKBOX_SELECTEDICON)));
            cb.setIcon(new ImageIcon(ResourcesManager.getInstance().getImage(ResourcesManager.KEY_CHECKBOX_UNSELECTEDICON)));
        } catch (final IOException e) {
            GuiUtils.showWarning(e, null);
            LOGGER.warn(e.getMessage(), e);
        }

        UIManager.getDefaults().put("CheckBox.background",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_CHECKBOX_BACKGROUND));
        UIManager.getDefaults().put("CheckBox.foreground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_CHECKBOX_FOREGROUND));
        return checkBoxUI;
    }

}
