/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import java.awt.Cursor;
import java.awt.Graphics;
import java.awt.Rectangle;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.SwingConstants;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicComboBoxUI;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The 3D Scan Manager personalized panel UI.
 *
 * @author Zleurtor
 */
public class ScanManagerComboBoxUI extends BasicComboBoxUI {

    /**
     * Create the UI.
     *
     * @param c The component to which the UI shall be applied.
     * @return The unique UI instance.
     */
    public static ComponentUI createUI(final JComponent c) {
        final ScanManagerComboBoxUI comboBoxUI = new ScanManagerComboBoxUI();

        final JComboBox<?> cb = ((JComboBox<?>) c);
        cb.setOpaque(false);
        cb.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));

        UIManager.getDefaults().put("ComboBox.background",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_COMBOBOX_BACKGROUND));
        UIManager.getDefaults().put("ComboBox.foreground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_COMBOBOX_FOREGROUND));
        UIManager.getDefaults().put("ComboBox.border",
                BorderFactory.createCompoundBorder(
                        BorderFactory.createLineBorder(ResourcesManager.getInstance().getColor(ResourcesManager.KEY_COMBOBOX_BORDER)),
                        BorderFactory.createEmptyBorder(
                                ResourcesManager.getInstance().getInt(ResourcesManager.KEY_COMBOBOX_BORDERINSETS_TOP),
                                ResourcesManager.getInstance().getInt(ResourcesManager.KEY_COMBOBOX_BORDERINSETS_LEFT),
                                ResourcesManager.getInstance().getInt(ResourcesManager.KEY_COMBOBOX_BORDERINSETS_BOTTOM),
                                ResourcesManager.getInstance().getInt(ResourcesManager.KEY_COMBOBOX_BORDERINSETS_RIGHT))));
        UIManager.getDefaults().put("ComboBox.selectionBackground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_COMBOBOX_SELECTIONBACKGROUND));
        UIManager.getDefaults().put("ComboBox.selectionForeground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_COMBOBOX_SELECTIONFOREGROUND));

        return comboBoxUI;
    }

    @Override
    public final void paint(final Graphics g, final JComponent c) {
        if (!comboBox.isEditable()) {
            final Rectangle r = rectangleForCurrentValue();
            paintCurrentValue(g, r, hasFocus);
        }
    }

    @Override
    protected final JButton createArrowButton() {
        final JButton c = new ScanManagerArrowButton(SwingConstants.SOUTH);
        c.setForeground(ResourcesManager.getInstance().getColor(ResourcesManager.KEY_COMBOBOX_FOREGROUND));
        return c;
    }

}
