/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import java.io.IOException;

import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JFileChooser;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.metal.MetalFileChooserUI;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import zleurtor.scanmanager.view.ResourcesManager;
import zleurtor.scanmanager.view.gui.GuiUtils;


/**
 * The 3D Scan Manager personalized panel UI.
 *
 * @author Zleurtor
 */
public class ScanManagerFileChooserUI extends MetalFileChooserUI {

    /**
     * A logger...
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(ScanManagerFileChooserUI.class);

    /**
     * Constructs a new component UI for the specified file chooser.
     *
     * @param b The file chooser for which the component UI shall be constructed.
     */
    public ScanManagerFileChooserUI(final JFileChooser b) {
        super(b);
    }

    /**
     * Create the UI.
     *
     * @param c The component to which the UI shall be applied.
     * @return The unique UI instance.
     */
    public static ComponentUI createUI(final JComponent c) {
        final ScanManagerFileChooserUI fileChooserUI = new ScanManagerFileChooserUI((JFileChooser) c);

        try {
            UIManager.getDefaults().put("FileView.fileIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILEVIEW_FILEICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            UIManager.getDefaults().put("FileView.floppyDriveIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILEVIEW_FLOPPYDRIVEICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            UIManager.getDefaults().put("FileView.computerIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILEVIEW_COMPUTERICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            UIManager.getDefaults().put("FileView.hardDriveIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILEVIEW_HARDDRIVEICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            UIManager.getDefaults().put("FileView.directoryIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILEVIEW_DIRECTORYICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));

            UIManager.getDefaults().put("FileChooser.upFolderIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILECHOOSER_UPFOLDERICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            UIManager.getDefaults().put("FileChooser.newFolderIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILECHOOSER_NEWFOLDERICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            UIManager.getDefaults().put("FileChooser.homeFolderIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILECHOOSER_HOMEFOLDERICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            UIManager.getDefaults().put("FileChooser.listViewIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILECHOOSER_LISTVIEWICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
            UIManager.getDefaults().put("FileChooser.detailsViewIcon",
                    new ImageIcon(ResourcesManager.colorize(
                            ResourcesManager.getInstance().getImage(ResourcesManager.KEY_FILECHOOSER_DETAILSVIEWICON),
                            ResourcesManager.getInstance().getColor(ResourcesManager.KEY_BUTTON_ACTIVE))));
        } catch (final IOException e) {
            GuiUtils.showWarning(e, null);
            LOGGER.warn(e.getMessage(), e);
        }

        return fileChooserUI;
    }

    @Override
    public final void installComponents(final JFileChooser fc) {
        super.installComponents(fc);
    }

}
