/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicListUI;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The 3D Scan Manager personalized label UI.
 *
 * @author Zleurtor
 */
public class ScanManagerListUI extends BasicListUI {

    /**
     * Create the UI.
     *
     * @param c The component to which the UI shall be applied.
     * @return The unique UI instance.
     */
    public static ComponentUI createUI(final JComponent c) {
        final ScanManagerListUI listUI = new ScanManagerListUI();

        UIManager.getDefaults().put("List.background",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_LIST_BACKGROUND));
        UIManager.getDefaults().put("List.foreground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_LIST_FOREGROUND));
        UIManager.getDefaults().put("List.selectionBackground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_LIST_SELECTIONBACKGROUND));
        UIManager.getDefaults().put("List.selectionForeground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_LIST_SELECTIONFOREGROUND));
        UIManager.getDefaults().put("List.focusCellHighlightBorder", BorderFactory.createEmptyBorder());

        return listUI;
    }

}
