/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import javax.swing.UIDefaults;
import javax.swing.plaf.metal.MetalLookAndFeel;

/**
 * The 3D Scan Manager personalized look and feel.
 *
 * @author Zleurtor
 */
public class ScanManagerLookAndFeel extends MetalLookAndFeel {

    private static final long serialVersionUID = -7452796553579098409L;

    @Override
    protected final void initClassDefaults(final UIDefaults table) {
        super.initClassDefaults(table);

        // UIs
        table.put("PanelUI", "zleurtor.scanmanager.view.plaf.ScanManagerPanelUI");
        table.put("ButtonUI", "zleurtor.scanmanager.view.plaf.ScanManagerButtonUI");
        table.put("LabelUI", "zleurtor.scanmanager.view.plaf.ScanManagerLabelUI");
        table.put("TextFieldUI", "zleurtor.scanmanager.view.plaf.ScanManagerTextFieldUI");
        table.put("ToolBarUI", "zleurtor.scanmanager.view.plaf.ScanManagerToolBarUI");
        table.put("ScrollPaneUI", "zleurtor.scanmanager.view.plaf.ScanManagerScrollPaneUI");
        table.put("ScrollBarUI", "zleurtor.scanmanager.view.plaf.ScanManagerScrollBarUI");
        table.put("OptionPaneUI", "zleurtor.scanmanager.view.plaf.ScanManagerOptionPaneUI");
        table.put("SpinnerUI", "zleurtor.scanmanager.view.plaf.ScanManagerSpinnerUI");
        table.put("FormattedTextFieldUI", "zleurtor.scanmanager.view.plaf.ScanManagerFormattedTextFieldUI");
        table.put("ComboBoxUI", "zleurtor.scanmanager.view.plaf.ScanManagerComboBoxUI");
        table.put("FileChooserUI", "zleurtor.scanmanager.view.plaf.ScanManagerFileChooserUI");
        table.put("ListUI", "zleurtor.scanmanager.view.plaf.ScanManagerListUI");
        table.put("ToggleButtonUI", "zleurtor.scanmanager.view.plaf.ScanManagerToggleButtonUI");
        table.put("SeparatorUI", "zleurtor.scanmanager.view.plaf.ScanManagerSeparatorUI");
        table.put("ToolTipUI", "zleurtor.scanmanager.view.plaf.ScanManagerToolTipUI");
        table.put("ProgressBarUI", "zleurtor.scanmanager.view.plaf.ScanManagerProgressBarUI");
        table.put("CheckBoxUI", "zleurtor.scanmanager.view.plaf.ScanManagerCheckBoxUI");
        table.put("TabbedPaneUI", "zleurtor.scanmanager.view.plaf.ScanManagerTabbedPaneUI");
        table.put("SliderUI", "zleurtor.scanmanager.view.plaf.ScanManagerSliderUI");
    }

    @Override
    public final String getName() {
        return "3D Scan Manager";
    }

    @Override
    public final String getID() {
        return "3d-scan-manager";
    }

    @Override
    public final String getDescription() {
        return "The 3D Scan Manager (tm) look and feel";
    }

    @Override
    public final boolean isNativeLookAndFeel() {
        return false;
    }

    @Override
    public final boolean isSupportedLookAndFeel() {
        return true;
    }

}
