/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.RenderingHints;

import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JScrollBar;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicScrollBarUI;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The 3D Scan Manager personalized scroll bar UI.
 *
 * @author Zleurtor
 */
public class ScanManagerScrollBarUI extends BasicScrollBarUI {

    /**
     * Create the UI.
     *
     * @param c The component to which the UI shall be applied.
     * @return The unique UI instance.
     */
    public static ComponentUI createUI(final JComponent c) {
        final ScanManagerScrollBarUI scrollBarUI = new ScanManagerScrollBarUI();

        UIManager.getDefaults().put("ScrollBar.background",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_SCROLLBAR_BACKGROUND));
        UIManager.getDefaults().put("ScrollBar.foreground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_SCROLLBAR_FOREGROUND));

        return scrollBarUI;
    }

    @Override
    public final void installUI(final JComponent c) {
        super.installUI(c);

        incrButton.setBorderPainted(false);
        incrButton.setBackground(c.getBackground());
        decrButton.setBorderPainted(false);
        decrButton.setBackground(c.getBackground());
    }

    @Override
    protected final void paintTrack(final Graphics g, final JComponent c, final Rectangle trackBounds) {
        if (c.isOpaque()) {
            g.setColor(c.getBackground());
            g.fillRect(0, 0, c.getWidth(), c.getHeight());
        }
    }

    @Override
    protected final void paintThumb(final Graphics g, final JComponent c, final Rectangle thumbBounds) {
        ((Graphics2D) g).setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);

        final int padding = 2;

        g.setColor(c.getForeground());
        if (((JScrollBar) c).getOrientation() == JScrollBar.VERTICAL) {
            g.fillRect(thumbBounds.x + padding, thumbBounds.y + padding, thumbBounds.width - padding * 2, thumbBounds.height - padding * 2);
        } else {
            g.fillRect(thumbBounds.x + padding, thumbBounds.y + padding, thumbBounds.width - padding * 2, thumbBounds.height - padding * 2);
        }
    }

    @Override
    protected final JButton createDecreaseButton(final int orientation) {
        final JButton c = new ScanManagerArrowButton(orientation);
        c.setForeground(ResourcesManager.getInstance().getColor(ResourcesManager.KEY_SCROLLBAR_FOREGROUND));
        return c;
    }

    @Override
    protected final JButton createIncreaseButton(final int orientation) {
        final JButton c = new ScanManagerArrowButton(orientation);
        c.setForeground(ResourcesManager.getInstance().getColor(ResourcesManager.KEY_SCROLLBAR_FOREGROUND));
        return c;
    }

}
