/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import java.awt.Graphics;

import javax.swing.JComponent;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicSeparatorUI;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The 3D Scan Manager personalized separator UI.
 *
 * @author Zleurtor
 */
public class ScanManagerSeparatorUI extends BasicSeparatorUI {

    /**
     * Create the UI.
     *
     * @param c The component to which the UI shall be applied.
     * @return The unique UI instance.
     */
    public static ComponentUI createUI(final JComponent c) {
        final ScanManagerSeparatorUI separatorUI = new ScanManagerSeparatorUI();

        UIManager.getDefaults().put("Separator.foreground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_SEPARATOR_FOREGROUND));

        return separatorUI;
    }

    @Override
    public final void paint(final Graphics g, final JComponent c) {
        g.drawLine(c.getWidth() / 2, 0, c.getWidth() / 2, c.getHeight());
    }

}
