/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import java.awt.Component;

import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JSpinner;
import javax.swing.SwingConstants;
import javax.swing.UIManager;
import javax.swing.JSpinner.NumberEditor;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicSpinnerUI;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The 3D Scan Manager personalized panel UI.
 *
 * @author Zleurtor
 */
public class ScanManagerSpinnerUI extends BasicSpinnerUI {

    /**
     * Create the UI.
     *
     * @param c The component to which the UI shall be applied.
     * @return The unique UI instance.
     */
    public static ComponentUI createUI(final JComponent c) {
        final ScanManagerSpinnerUI spinnerUI = new ScanManagerSpinnerUI();

        final JSpinner s = ((JSpinner) c);
        s.setOpaque(false);
        UIManager.getDefaults().put("Spinner.border",
                BorderFactory.createCompoundBorder(
                        BorderFactory.createLineBorder(ResourcesManager.getInstance().getColor(ResourcesManager.KEY_SPINNER_BORDER)),
                        BorderFactory.createEmptyBorder(
                                ResourcesManager.getInstance().getInt(ResourcesManager.KEY_SPINNER_BORDERINSETS_TOP),
                                ResourcesManager.getInstance().getInt(ResourcesManager.KEY_SPINNER_BORDERINSETS_LEFT),
                                ResourcesManager.getInstance().getInt(ResourcesManager.KEY_SPINNER_BORDERINSETS_BOTTOM),
                                ResourcesManager.getInstance().getInt(ResourcesManager.KEY_SPINNER_BORDERINSETS_RIGHT))));
        ((NumberEditor) s.getEditor()).setOpaque(false);
        for (final Component comp : ((NumberEditor) s.getEditor()).getComponents()) {
            if (comp instanceof JComponent) {
                ((JComponent) comp).setOpaque(false);
            }
        }

        return spinnerUI;
    }

    @Override
    protected final Component createNextButton() {
        final Component c = new ScanManagerArrowButton(SwingConstants.NORTH);
        c.setForeground(ResourcesManager.getInstance().getColor(ResourcesManager.KEY_SPINNER_FOREGROUND));
        c.setName("Spinner.nextButton");
        installNextButtonListeners(c);
        return c;
    }

    @Override
    protected final Component createPreviousButton() {
        final Component c = new ScanManagerArrowButton(SwingConstants.SOUTH);
        c.setForeground(ResourcesManager.getInstance().getColor(ResourcesManager.KEY_SPINNER_FOREGROUND));
        c.setName("Spinner.previousButton");
        installPreviousButtonListeners(c);
        return c;
    }

}
