/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import java.awt.Graphics;

import javax.swing.JComponent;
import javax.swing.JTabbedPane;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicTabbedPaneUI;

import zleurtor.scanmanager.view.ResourcesManager;

/**
 * The 3D Scan Manager personalized label UI.
 *
 * @author Zleurtor
 */
public class ScanManagerTabbedPaneUI extends BasicTabbedPaneUI {

    /**
     * Create the UI.
     *
     * @param c The component to which the UI shall be applied.
     * @return The unique UI instance.
     */
    public static ComponentUI createUI(final JComponent c) {
        final ScanManagerTabbedPaneUI tabbedPaneUI = new ScanManagerTabbedPaneUI();

        final JTabbedPane tp = (JTabbedPane) c;
        tp.setOpaque(false);
        UIManager.getDefaults().put("TabbedPane.contentOpaque", false);
        UIManager.getDefaults().put("TabbedPane.tabsOpaque", false);

        UIManager.getDefaults().put("TabbedPane.background",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_TABBEDPANE_BACKGROUND));
        UIManager.getDefaults().put("TabbedPane.foreground",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_TABBEDPANE_FOREGROUND));
        UIManager.getDefaults().put("TabbedPane.highlight",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_TABBEDPANE_HIGHLIGHT));
        UIManager.getDefaults().put("TabbedPane.light",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_TABBEDPANE_LIGHT));
        UIManager.getDefaults().put("TabbedPane.shadow",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_TABBEDPANE_SHADOW));
        UIManager.getDefaults().put("TabbedPane.darkShadow",
                ResourcesManager.getInstance().getColor(ResourcesManager.KEY_TABBEDPANE_DARKSHADOW));

        return tabbedPaneUI;
    }

    @Override
    protected final void paintTabBorder(final Graphics g, final int tabPlacement, final int tabIndex,
            final int x, final int y, final int w, final int h, final boolean isSelected) {
        g.setColor(lightHighlight);

        if (tabIndex == 0) {
            g.drawLine(x, y, x, y + h);
        } else if (isSelected) {
            g.drawLine(x + 2, y, x + 2, y + 2);
            g.drawLine(x, y + h - 2, x + 2, y + h - 2);
        }
        g.drawLine(x + (tabIndex > 0 ? 1 : 0), y, x + w, y);
        g.drawLine(x + w, y, x + w, y + h - (isSelected ? 2 : 0));
    }

}
