/*
 * 3D Scanner Manager
 * Copyright (c) 2021-2024 Zleurtor
 *
 * This file is part of 3D Scanner Manager.
 *
 * 3D Scanner Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * 3D Scanner Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with 3D Scanner Manager.  If not, see <https://www.gnu.org/licenses/>.
 */

package zleurtor.scanmanager.view.plaf;

import java.awt.Graphics;
import java.awt.Polygon;

import javax.swing.JComponent;
import javax.swing.JToolBar;
import javax.swing.UIManager;
import javax.swing.plaf.ComponentUI;
import javax.swing.plaf.basic.BasicToolBarUI;

import zleurtor.scanmanager.view.ResourcesManager;
import zleurtor.scanmanager.view.gui.ToolBarBorder;


/**
 * The 3D Scan Manager personalized tool bar UI.
 *
 * @author Zleurtor
 */
public class ScanManagerToolBarUI extends BasicToolBarUI {

    /**
     * Create the UI.
     *
     * @param c The component to which the UI shall be applied.
     * @return The unique UI instance.
     */
    public static ComponentUI createUI(final JComponent c) {
        final ScanManagerToolBarUI toolBarUI = new ScanManagerToolBarUI();

        final JToolBar tb = (JToolBar) c;
        tb.setOpaque(false);
        tb.setBorder(new ToolBarBorder());

        UIManager.getDefaults().put("ToolBar.background",
                    ResourcesManager.getInstance().getColor(ResourcesManager.KEY_TOOLBAR_BACKGROUND));

        return toolBarUI;
    }

    @Override
    public final void paint(final Graphics g, final JComponent c) {
        final Polygon p = new Polygon(
                new int[] { 0, c.getBorder().getBorderInsets(c).left, c.getWidth() - c.getBorder().getBorderInsets(c).right, c.getWidth() },
                new int[] { 0, c.getHeight(), c.getHeight(), 0 },
                4);
        g.setColor(c.getBackground());
        g.fillPolygon(p);

        super.paint(g, c);
    }

}
